@@ -15,6 +15,7 @@ import time
 from inspect import getmembers,isfunction,ismethod
 import sys
 
+
 class ApplicationConfigurator():
 
     def get(self,config_key):
@@ -46,6 +47,7 @@ class ApplicationConfigurator():
 
 class KafkaConfig(object):
     def __init__(self, kafka_brokers, json=False):
+        print(kafka_brokers)
         self.json = json
         if not json:
             self.producer = KafkaProducer(
@@ -66,12 +68,11 @@ class KafkaConfig(object):
 
 class FerrisKafkaLoggingHandler(StreamHandler):
 
-    def __init__(self,topic):
+    def __init__(self,topic='ferris.logs'):
         StreamHandler.__init__(self)
-        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
         self.topic = topic
         # Kafka Broker Configuration
-        self.kafka_broker = KafkaConfig(self.broker)
+        self.kafka_broker = KafkaConfig(broker_url)
 
         STRING_FORMAT = '''{
         "Levelname":       "levelname",
@@ -108,10 +109,9 @@ class MetricsAPI:
 
 
     def __init__(self, topic='ferris.metrics'):
-        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
         self.topic = topic
         # Kafka Broker Configuration
-        self.kafka_broker = KafkaConfig(self.broker)
+        self.kafka_broker = KafkaConfig(broker_url)
         print('metrics init called')
 
     def send(self,metric_message:MetricMessage):
@@ -125,10 +125,9 @@ class MetricsAPI:
 class CloudEventsAPI():
 
     def __init__(self, topic='ferris.cloudevents'):
-        self.broker = os.environ['KAFKA_BOOTSTRAP_SERVER'] + ':' + os.environ['KAFKA_PORT']
         self.topic = topic
         # Kafka Broker Configuration
-        self.kafka_broker = KafkaConfig(self.broker)
+        self.kafka_broker = KafkaConfig(broker_url)
     def send(self, event):
         event.SetEventID(uuid.uuid1().hex)
         date_time = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
@@ -175,4 +174,7 @@ class ExecutionTime:
             for name,addr in items:
                 setattr(module,name,self.timeit(addr))
         except KeyError as e:
-            raise f'Error Occured, No module by name {module_name}. If you think this was a mistake than raise issue at {self.issue_url}'
\ No newline at end of file
+            raise f'Error Occured, No module by name {module_name}. If you think this was a mistake than raise issue at {self.issue_url}'
+
+environment = ApplicationConfigurator().get('ferris.env')
+broker_url = f"{environment['KAFKA_BOOTSTRAP_SERVER']}:{environment['KAFKA_PORT']}"
\ No newline at end of file
